<?php

namespace Drupal\usage_data\Plugin\UsageType;

use Drupal\usage_data\Plugin\UsageTypePluginBase;
use Drupal\usage_data\UsageDataInterface;

/**
 * Plugin implementation of the Generic UsageType.
 *
 * @UsageType(
 *   id = "generic",
 *   label = @Translation("Generic Usage Data"),
 *   description = @Translation("Tracks all events of all types.")
 * )
 */
class Generic extends UsageTypePluginBase {

  /**
   * The most common front-end viewable entities.
   */
  const ENTITY_TYPES = ['node', 'taxonomy_term', 'media', 'commerce_product'];

  /**
   * Only track full/default view modes.
   */
  const ENTITY_VIEW_MODES = ['default', 'full'];

  /**
   * {@inheritDoc}
   */
  public function parseEvent($eventType, $entityTypeId, $entityId, $path = NULL, array &$render = [], $viewMode = FALSE) {
    if ((in_array($entityTypeId, self::ENTITY_TYPES) && in_array($viewMode, self::ENTITY_VIEW_MODES)) ||
      in_array($entityTypeId, UsageDataInterface::OTHER_ENTITY_TYPES) ||
      $eventType == UsageDataInterface::EVENT_TYPE_CLICK) {
      return $this->defaultData($eventType, $entityTypeId, $entityId, $path);
    }
    return FALSE;
  }

  /**
   * {@inheritDoc}
   */
  public static function validateEvent(array &$data) {
    $allowed_Types = self::ENTITY_TYPES + UsageDataInterface::OTHER_ENTITY_TYPES;
    if (!in_array($data['entity_type_id'], $allowed_Types)) {
      $data['skip'] = TRUE;
    }
    parent::validateEvent($data);
  }

}
