<?php

namespace Drupal\usage_data;

/**
 * Usage Data storage interface.
 */
interface UsageDataStorageInterface {

  /**
   * Records Usage keyed by type.
   *
   * @param array $data
   *   The data to insert.
   */
  public function recordUsage(array $data);

  /**
   * Record typed usage.
   *
   * Inserts are done in a single transaction for performance reasons.
   *
   * @param string $type
   *   The type of usage to store.
   * @param array $data
   *   The data to insert.
   *
   * @return bool
   *   TRUE if the usage has been stored.
   */
  public function recordUsageByType($type, array $data);

  /**
   * Fetches usage data from the appropriate table.
   *
   * @param $type
   *   The type of usage data to fetch.
   * @param string $eventType
   *   The optional event type
   * @param string $entityTypeId
   *   The optional entity type id.
   * @param string $entityId
   *   The optional entity id
   * @param bool $count
   *   Whether this should be a count query or not.
   * @param array $conditions
   *   Additional conditions to add to the query.
   *
   * @return \Drupal\Core\Database\StatementInterface | mixed
   *   Either the executed query or the count.
   */
  public function fetchUsageData($type, $eventType = NULL, $entityTypeId = NULL, $entityId = NULL, $count = TRUE, $conditions = []);

  /**
   * Delete usage data from all tables.
   *
   * @param int $entityTypeId
   *   The target entity type id.
   * @param int $entityId
   *   The target entity id.
   */
  public function deleteUsageData($entityTypeId, $entityId);

  /**
   * Defines the default schema for usage plugins.
   *
   * @return array
   *   The default schema.
   */
  public function defaultSchema();

  /**
   * Creates a table by type.
   *
   * @param string $type
   *   The type of usage.
   */
  public function createTable($type);

  /**
   * Drops a table by type.
   *
   * @param string $type
   *   The type of usage.
   */
  public function dropTable($type);

}
